@@ -2,7 +2,7 @@
 # Distributed under the terms of the GNU General Public License v2
 
 import signal
-from portage import _encodings, _unicode_encode, _unicode_decode
+from portage import _encodings, _unicode_decode
 from portage.localization import _
 
 
@@ -14,8 +14,7 @@ class PortageException(Exception):
 	def __str__(self):
 		if isinstance(self.value, str):
 			return self.value
-		else:
-			return repr(self.value)
+		return repr(self.value)
 
 
 class PortageKeyError(KeyError, PortageException):
